@@ -290,6 +290,8 @@ def api_external_get_mo(request):
 
         token = request.token
 
+        all_mo = get_parameter(request, "all"):
+
         try:
             recorder = \
                 Recorder.objects.filter(token=token)[0]
@@ -300,8 +302,11 @@ def api_external_get_mo(request):
             res["response"]=response
             return json_response(res)
 
-        recordings_list = Recording.objects\
-            .filter(to_delete=False).iterator()
+        if all_mo:
+            recordings_list = Recording.objects.iterator()
+        else:
+            recordings_list = Recording.objects\
+                .filter(to_delete=False).iterator()
 
         response = []
         for r in recordings_list:
@@ -310,6 +315,17 @@ def api_external_get_mo(request):
                 logger.debug("Getting profiles for %s : %s" % (r,r.profiles_json))
                 for p in profiles:
                     response.append(p["destination"])
+                metadatas = json.logger(r.metadata_json)
+                logger.debug("Getting smil for %s : %s" % (r,r.metadata_json))
+                for m in metadatas:
+                    try:
+                        k = m.keys()[0]
+                        v = m.value()[0]
+                        if k == "smil":
+                            response.append(v)
+                    except Exception:
+                        pass
+
             except Exception as e:
                 logger.error( "Exception occurs getting profiles for %s: %s"% (r,e))
         res["response"]=response
